==> nextcloud-19.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ps.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "کړنې",
    "An error occurred while loading activities" : "د کړنو د لیدلو په وخت کې يوه ستونزه رامنځ ته شوه.",
    "No activity yet" : "تر اوسه کړنې نشته",
    "Load more activities" : "نورې کړنې پرانيستل",
    "Copied!" : "کاپي شو!",
    "Not supported!" : "د کار نه کېږي",
    "Press ⌘-C to copy." : "د کاپي لپاره د ⌘-C تڼۍ کېکاږئ.",
    "Press Ctrl-C to copy." : "د کاپي لپاره د Ctrl-C تڼۍ کېکاږئ.",
    "{name} (invisible)" : "{name} (پټ دی)",
    "{name} (restricted)" : "{name} (تړلی دی)",
    "Home" : "کور",
    "in {path}" : "په {path} کې",
    "This stream will show events like additions, changes & shares" : "په دې ځای کې به د ډېرېدلو، تغیراتو او شريکېدو کړې اوسي",
    "There are no events for this filter" : "دا ډول کړنې نشته",
    "Today" : "نن",
    "Yesterday" : "پرون",
    "Open file" : "فایل پرانيستل",
    "Personal activity feed for %s" : "د %s لپاره شخصي د کړنو لړ",
    "Your feed URL is invalid" : "ستاسې لېنک ناسم دی",
    "Your settings have been updated." : "په سمونو کې بدلون ثبت شو",
    "Settings have been updated." : "په سمونو کې بدلون ثبت شو",
    "All activities" : "ټولې کړنې",
    "By others" : "د نورو لخوا",
    "By you" : "ستاسې لخوا",
    "Activity notification for %s" : "%s لپاره خبرتیا",
    "Hello %s" : "سلامونه %s",
    "Hello %s," : "سلامونه %s،",
    "There was some activity at %s" : "په %s کې يو څه فعاليت و",
    "_and %n more _::_and %n more _" : ["او %n نور","او %n نورې"],
    "Mail" : "ایمیل",
    "Stream" : "لېست",
    "This application enables users to view actions related to their files in Nextcloud." : "دغه اپلیکیشن کاروونکو ته دا اجازه ورکوي په Nextcloud کې خپلو دوتنو ته ورته کړنې وويني.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "دغه اپلیکیشن کاروونکو ته دا اجازه ورکوي په Nextcloud کې خپلو دوتنو ته ورته کړنې وويني. د اجازې په صورت کې به کاروونکي د خپلو اپليکېشنونو پر مخ د \"کړنې\" په نوم نوې نښه وويني. د کړنې په پاڼه کې کاروونکي، له نويو دوتنو نيولې تر پاکو شويو، خوځول شويو، بيا نومول شويو، تازه شويو او شريکې شويو دوتنو اړوند ټولې کړنې څارلی او کتلی شي. هر کاروونکی د شخصي پاڼې په تنظيماتو کې خپلې کړنې ترتيبولی شي. کاروونکي د کړنې ډول د ريکارډ په ډول ساتلی شي او يا داسې چې يوازې دوئ خپلې کړنې وويني. داسې هم کېږي چې دغه کړنې يوازې انلاين موجودې وي او يا يې د ايمېل له لارې په دوامداره ډول ترلاسه کړي. نور معلومات د کړنې په اسنادو کې موجود دي. ",
    "Activity feed" : "د کړنو لېست",
    "Send activity emails" : "کړنې په ايمیل کې لېږل",
    "Default settings" : "اصلي حالت",
    "Configure the default activity settings for new users." : "نويو کاروونکو ته د کړنې اساسي تنظيمات ترتيب کړئ",
    "List your own actions in the stream" : "خپل فعاليتونه په بهير کې لېسټ کړئ",
    "Notify about your own actions via email" : "د ايمېل له لارې د خپلو فعاليتونو په اړه خبر شئ.",
    "You need to set up your email address before you can receive notification emails." : "د خبرتياوو ترلاسه کولو نه مخکې بايد خپل ايمېل ادرس ترتيب کړئ.",
    "Send emails:" : "ايمېل ولېږئ",
    "As soon as possible" : "ژر تر ژره",
    "Hourly" : "ساعت وار",
    "Daily" : "روزانه",
    "Weekly" : "هفته وار",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "هغه کړنې انتخاب کړئ چې تاسې غواړئ په اړه يې ايمېل ترلاسه کړئ او د کړنو اپليکيشن په بهير کې را ښکاره شي.",
    "Choose which activities you want to see in your stream." : "د خپل بهير لپاره هغه کړنې انتخاب کړئ چې غواړئ ويې وينئ",
    "Settings" : "سمونې",
    "Enable RSS feed" : "RRS لړ فعال کړئ",
    "RSS feed" : "RRS لړ ",
    "No more events to load" : "نورې کړنې نشته"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ps.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "د %s لپاره شخصي د کړنو لړ",
    "Your feed URL is invalid" : "ستاسې لېنک ناسم دی",
    "Activity feed" : "د کړنو لېست",
    "Your settings have been updated." : "په سمونو کې بدلون ثبت شو",
    "Settings have been updated." : "په سمونو کې بدلون ثبت شو",
    "_and %n more _::_and %n more _" : ["او %n نور","او %n نورې"],
    "All activities" : "ټولې کړنې",
    "By others" : "د نورو لخوا",
    "By you" : "ستاسې لخوا",
    "Hello %s" : "سلامونه %s",
    "Hello %s," : "سلامونه %s،",
    "There was some activity at %s" : "په %s کې يو څه فعاليت و",
    "Mail" : "ایمیل",
    "Activity" : "کړنې",
    "Today" : "نن",
    "Yesterday" : "پرون",
    "You need to set up your email address before you can receive notification emails." : "د خبرتياوو ترلاسه کولو نه مخکې بايد خپل ايمېل ادرس ترتيب کړئ.",
    "Send activity emails" : "کړنې په ايمیل کې لېږل",
    "As soon as possible" : "ژر تر ژره",
    "Hourly" : "ساعت وار",
    "Daily" : "روزانه",
    "Weekly" : "هفته وار",
    "You commented" : "تاسې تبصره کړې",
    "in {path}" : "په {path} کې",
    "Home" : "کور",
    "This stream will show events like additions, changes & shares" : "په دې ځای کې به د ډېرېدلو، تغیراتو او شريکېدو کړې اوسي",
    "No activity yet" : "تر اوسه کړنې نشته",
    "Enable RSS feed" : "RRS لړ فعال کړئ",
    "RSS feed" : "RRS لړ ",
    "Default settings" : "اصلي حالت",
    "No more events to load" : "نورې کړنې نشته",
    "Copied!" : "کاپي شو!",
    "Not supported!" : "د کار نه کېږي",
    "Press ⌘-C to copy." : "د کاپي لپاره د ⌘-C تڼۍ کېکاږئ.",
    "Press Ctrl-C to copy." : "د کاپي لپاره د Ctrl-C تڼۍ کېکاږئ.",
    "{name} (invisible)" : "{name} (پټ دی)",
    "{name} (restricted)" : "{name} (تړلی دی)",
    "There are no events for this filter" : "دا ډول کړنې نشته",
    "Activities" : "کړنې"
},
"nplurals=2; plural=(n != 1);");
